@@ -30,19 +30,17 @@
  *   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  $Id: fcntl.c,v 1.19 2007/03/02 07:39:05 shirok Exp $
+ *  $Id: fcntl.c,v 1.23 2007/11/10 02:52:04 shirok Exp $
  */
 
 #define _GNU_SOURCE  /* for Linux, this enables additional features */
 
+#include <gauche.h>
 #include <string.h>
 #include <errno.h>
-#include <gauche.h>
 #include <gauche/class.h>
 #include <gauche/extend.h>
 
-#undef SCM_EXTERN
-#define SCM_EXTERN  extern
 #include "gauche/fcntl.h"
 
 /* struct flock */
@@ -62,20 +60,20 @@ static ScmObj flock_allocate(ScmClass *klass, ScmObj initargs)
     return SCM_OBJ(f);
 }
 
-#define FLOCK_GET_N_SET(name, type)                                       \
+#define FLOCK_GET_N_SET(name, type, make, get)                            \
   static ScmObj SCM_CPP_CAT3(flock_, name, _get)(ScmSysFlock* t)          \
-  { return Scm_MakeInteger(t->lock.name); }                               \
+  { return make(t->lock.name); }                                          \
   static void SCM_CPP_CAT3(flock_, name, _set)(ScmSysFlock* t, ScmObj v)  \
   {                                                                       \
       if (!SCM_INTEGERP(v)) Scm_Error("integer required, but got %S", v); \
-      t->lock.name = (type)Scm_GetInteger(v);                             \
+      t->lock.name = (type)get(v);                                        \
   }
 
-FLOCK_GET_N_SET(l_type, short)
-FLOCK_GET_N_SET(l_whence, short)
-FLOCK_GET_N_SET(l_start, off_t)
-FLOCK_GET_N_SET(l_len, off_t)
-FLOCK_GET_N_SET(l_pid, pid_t)
+FLOCK_GET_N_SET(l_type, short, Scm_MakeInteger, Scm_GetInteger)
+FLOCK_GET_N_SET(l_whence, short, Scm_MakeInteger, Scm_GetInteger)
+FLOCK_GET_N_SET(l_start, off_t, Scm_OffsetToInteger, Scm_IntegerToOffset)
+FLOCK_GET_N_SET(l_len, off_t, Scm_OffsetToInteger, Scm_IntegerToOffset)
+FLOCK_GET_N_SET(l_pid, pid_t, Scm_MakeInteger, Scm_GetInteger)
 
 static ScmClassStaticSlotSpec flock_slots[] = {
     SCM_CLASS_SLOT_SPEC("type",   flock_l_type_get, flock_l_type_set),
@@ -83,7 +81,7 @@ static ScmClassStaticSlotSpec flock_slots[] = {
     SCM_CLASS_SLOT_SPEC("start",  flock_l_start_get, flock_l_start_set),
     SCM_CLASS_SLOT_SPEC("len",    flock_l_len_get, flock_l_len_set),
     SCM_CLASS_SLOT_SPEC("pid",    flock_l_pid_get, flock_l_pid_set),
-    { NULL }
+    SCM_CLASS_SLOT_SPEC_END()
 };
 
 ScmObj Scm_MakeSysFlock(void)
@@ -134,7 +132,7 @@ static const char *flag_name(int flag)
 
 ScmObj Scm_SysFcntl(ScmObj port_or_fd, int op, ScmObj arg)
 {
-#ifndef __MINGW32__
+#if !defined(GAUCHE_WINDOWS)
     int fd = Scm_GetPortFd(port_or_fd, TRUE), r;
     ScmSysFlock *fl;
     
@@ -193,10 +191,10 @@ ScmObj Scm_SysFcntl(ScmObj port_or_fd, int op, ScmObj arg)
         Scm_Error("unknown operation code (%d) for fcntl", op);
         return SCM_UNDEFINED;   /* dummy */
     }
-#else  /*__MINGW32__*/
+#else  /*GAUCHE_WINDOWS*/
     Scm_Error("fcntl not supported on MinGW port");
     return SCM_UNDEFINED; /*dummy*/
-#endif /*__MINGW32__*/
+#endif /*GAUCHE_WINDOWS*/
 }
 
 /*
@@ -205,7 +203,7 @@ ScmObj Scm_SysFcntl(ScmObj port_or_fd, int op, ScmObj arg)
 
 extern void Scm_Init_fcntlib(ScmModule *mod);
 
-void Scm_Init_fcntl(void)
+SCM_EXTENSION_ENTRY void Scm_Init_fcntl(void)
 {
     ScmModule *mod;
 
@@ -215,7 +213,7 @@ void Scm_Init_fcntl(void)
                         mod, flock_slots, 0);
     Scm_Init_fcntlib(mod);
 
-#ifndef __MINGW32__
+#ifndef GAUCHE_WINDOWS
     Scm_AddFeature("gauche.sys.fcntl", NULL);
 #endif
 }
